==> 1.1.5.tar.gz: lib/Metrix.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

import 'MetrixAttribution.dart';

import 'dart:io' show Platform;

class Metrix {

  static var shouldLaunchDeeplink = true;

  static const MethodChannel _channel = const MethodChannel('Metrix');

  static void newEvent(String slug, Map<String, String> attributes) {
    if (Platform.isAndroid) {
      _channel.invokeMethod('newEvent', {
        'slug': slug,
        'attributes': attributes,
      });
    }
  }

  static void addUserAttributes(Map<String, String> attributes) {
    if (Platform.isAndroid) {
      _channel.invokeMethod('addUserAttributes', {
        'attributes': attributes
      });
    }
  }

  static void newRevenue(String slug, double amount, int currency, String orderId) {
    if (Platform.isAndroid) {
      _channel.invokeMethod('newRevenue', {
        'slug': slug,
        'amount': amount,
        'currency': currency,
        'orderId': orderId
      });
    }
  }

  static void setPushToken(String token) {
    if (Platform.isAndroid) {
      _channel.invokeMethod('setPushToken', {
        'token': token
      });
    }
  }

  static Future<int> getSessionNumber() async {
    if (Platform.isAndroid) {
      final int sessionNum = await _channel.invokeMethod('getSessionNumber');
      return sessionNum;
    } else {
      return 0;
    }
  }

  static Future<String> getSessionId() async {
    if (Platform.isAndroid) {
      final String sessionId = await _channel.invokeMethod('getSessionId');
      return sessionId;
    } else {
      return "";
    }
  }

  static Future<String> getUserId() async {
    if (Platform.isAndroid) {
      final String id = await _channel.invokeMethod('setUserIdListener');
      return id;
    } else {
      return "";
    }
  }

  static void setShouldLaunchDeeplink(bool shouldLaunch) {
    shouldLaunchDeeplink = shouldLaunch;
  }

  static Future<MetrixAttribution> getAttributionData() async {
    if (Platform.isAndroid) {
      final Map attribution = await _channel.invokeMethod('getAttributionData');
      return MetrixAttribution.fromMap(attribution);
    } else {
      return new MetrixAttribution();
    }
  }

  static Future<String> getDeeplinkResponse() async {
    if (Platform.isAndroid) {
      final String deeplink = await _channel.invokeMethod('getDeeplinkResponse', {
        'shouldLaunchDeeplink': shouldLaunchDeeplink
      });
      return deeplink;
    } else {
      return "";
    }
  }
}

==> 1.1.8.tar.gz: lib/Metrix.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/foundation.dart';

import 'MetrixAttribution.dart';

import 'dart:io' show Platform;

class Metrix {

  static var shouldLaunchDeeplink = true;

  static bool get isIOS => !kIsWeb && Platform.isIOS;
  static bool get isAndroid => !kIsWeb && Platform.isAndroid;
  static bool get isWeb => kIsWeb;

  static const MethodChannel _channel = const MethodChannel('Metrix');

  static void newEvent(String slug, [Map<String, String> attributes = const {}]) {
    if (isAndroid) {
      _channel.invokeMethod('newEvent', {
        'slug': slug,
        'attributes': attributes,
      });
    }
  }

  static void addUserAttributes(Map<String, String> attributes) {
    if (isAndroid) {
      _channel.invokeMethod('addUserAttributes', {
        'attributes': attributes
      });
    }
  }

  static void newRevenue(String slug, double amount, {int currency = 0, String? orderId}) {
    if (isAndroid) {
      _channel.invokeMethod('newRevenue', {
        'slug': slug,
        'amount': amount,
        'currency': currency,
        'orderId': orderId
      });
    }
  }

  static void setPushToken(String token) {
    if (isAndroid) {
      _channel.invokeMethod('setPushToken', {
        'token': token
      });
    }
  }

  static Future<int> getSessionNumber() async {
    if (isAndroid) {
      final int sessionNum = await _channel.invokeMethod('getSessionNumber');
      return sessionNum;
    } else {
      return 0;
    }
  }

  static Future<String> getSessionId() async {
    if (isAndroid) {
      final String sessionId = await _channel.invokeMethod('getSessionId');
      return sessionId;
    } else {
      return "";
    }
  }

  static Future<String> getUserId() async {
    if (isAndroid) {
      final String id = await _channel.invokeMethod('setUserIdListener');
      return id;
    } else {
      return "";
    }
  }

  static void setShouldLaunchDeeplink(bool shouldLaunch) {
    shouldLaunchDeeplink = shouldLaunch;
  }

  static Future<MetrixAttribution> getAttributionData() async {
    if (isAndroid) {
      final Map attribution = await _channel.invokeMethod('getAttributionData');
      return MetrixAttribution.fromMap(attribution);
    } else {
      return new MetrixAttribution();
    }
  }

  static Future<String> getDeeplinkResponse() async {
    if (isAndroid) {
      final String deeplink = await _channel.invokeMethod('getDeeplinkResponse', {
        'shouldLaunchDeeplink': shouldLaunchDeeplink
      });
      return deeplink;
    } else {
      return "";
    }
  }
}
